function BranchData() {
    this.position = -1;
    this.nodeLength = -1;
    this.src = null;
    this.evalFalse = 0;
    this.evalTrue = 0;

    this.init = function(position, nodeLength, src) {
        this.position = position;
        this.nodeLength = nodeLength;
        this.src = src;
        return this;
    }

    this.ranCondition = function(result) {
        if (result)
            this.evalTrue++;
        else
            this.evalFalse++;
    };

    this.pathsCovered = function() {
        var paths = 0;
        if (this.evalTrue > 0)
          paths++;
        if (this.evalFalse > 0)
          paths++;
        return paths;
    };

    this.covered = function() {
        return this.evalTrue > 0 && this.evalFalse > 0;
    };

    this.toJSON = function() {
        return '{"position":' + this.position
            + ',"nodeLength":' + this.nodeLength
            + ',"src":' + jscoverage_quote(this.src)
            + ',"evalFalse":' + this.evalFalse
            + ',"evalTrue":' + this.evalTrue + '}';
    };

    this.message = function() {
        if (this.evalTrue === 0 && this.evalFalse === 0)
            return 'Condition never evaluated         :\t' + this.src;
        else if (this.evalTrue === 0)
            return 'Condition never evaluated to true :\t' + this.src;
        else if (this.evalFalse === 0)
            return 'Condition never evaluated to false:\t' + this.src;
        else
            return 'Condition covered';
    };
}

BranchData.fromJson = function(jsonString) {
    var json = eval('(' + jsonString + ')');
    var branchData = new BranchData();
    branchData.init(json.position, json.nodeLength, json.src);
    branchData.evalFalse = json.evalFalse;
    branchData.evalTrue = json.evalTrue;
    return branchData;
};

BranchData.fromJsonObject = function(json) {
    var branchData = new BranchData();
    branchData.init(json.position, json.nodeLength, json.src);
    branchData.evalFalse = json.evalFalse;
    branchData.evalTrue = json.evalTrue;
    return branchData;
};

function buildBranchMessage(conditions) {
    var message = 'The following was not covered:';
    for (var i = 0; i < conditions.length; i++) {
        if (conditions[i] !== undefined && conditions[i] !== null && !conditions[i].covered())
          message += '\n- '+ conditions[i].message();
    }
    return message;
};

function convertBranchDataConditionArrayToJSON(branchDataConditionArray) {
    var array = [];
    var length = branchDataConditionArray.length;
    for (var condition = 0; condition < length; condition++) {
        var branchDataObject = branchDataConditionArray[condition];
        if (branchDataObject === undefined || branchDataObject === null) {
            value = 'null';
        } else {
            value = branchDataObject.toJSON();
        }
        array.push(value);
    }
    return '[' + array.join(',') + ']';
}

function convertBranchDataLinesToJSON(branchData) {
    if (branchData === undefined) {
        return '{}'
    }
    var json = '';
    for (var line in branchData) {
        if (json !== '')
            json += ','
        json += '"' + line + '":' + convertBranchDataConditionArrayToJSON(branchData[line]);
    }
    return '{' + json + '}';
}

function convertBranchDataLinesFromJSON(jsonObject) {
    if (jsonObject === undefined) {
        return {};
    }
    for (var line in jsonObject) {
        var branchDataJSON = jsonObject[line];
        if (branchDataJSON !== null) {
            for (var conditionIndex = 0; conditionIndex < branchDataJSON.length; conditionIndex ++) {
                var condition = branchDataJSON[conditionIndex];
                if (condition !== null) {
                    branchDataJSON[conditionIndex] = BranchData.fromJsonObject(condition);
                }
            }
        }
    }
    return jsonObject;
}
function jscoverage_quote(s) {
    return '"' + s.replace(/[\u0000-\u001f"\\\u007f-\uffff]/g, function (c) {
        switch (c) {
            case '\b':
                return '\\b';
            case '\f':
                return '\\f';
            case '\n':
                return '\\n';
            case '\r':
                return '\\r';
            case '\t':
                return '\\t';
            // IE doesn't support this
            /*
             case '\v':
             return '\\v';
             */
            case '"':
                return '\\"';
            case '\\':
                return '\\\\';
            default:
                return '\\u' + jscoverage_pad(c.charCodeAt(0).toString(16));
        }
    }) + '"';
}

function getArrayJSON(coverage) {
    var array = [];
    if (coverage === undefined)
        return array;

    var length = coverage.length;
    for (var line = 0; line < length; line++) {
        var value = coverage[line];
        if (value === undefined || value === null) {
            value = 'null';
        }
        array.push(value);
    }
    return array;
}

function jscoverage_serializeCoverageToJSON() {
    var json = [];
    for (var file in _$jscoverage) {
        var lineArray = getArrayJSON(_$jscoverage[file].lineData);
        var fnArray = getArrayJSON(_$jscoverage[file].functionData);

        json.push(jscoverage_quote(file) + ':{"lineData":[' + lineArray.join(',') + '],"functionData":[' + fnArray.join(',') + '],"branchData":' + convertBranchDataLinesToJSON(_$jscoverage[file].branchData) + '}');
    }
    return '{' + json.join(',') + '}';
}


function jscoverage_pad(s) {
    return '0000'.substr(s.length) + s;
}

function jscoverage_html_escape(s) {
    return s.replace(/[<>\&\"\']/g, function (c) {
        return '&#' + c.charCodeAt(0) + ';';
    });
}
try {
  if (typeof top === 'object' && top !== null && typeof top.opener === 'object' && top.opener !== null) {
    // this is a browser window that was opened from another window

    if (! top.opener._$jscoverage) {
      top.opener._$jscoverage = {};
    }
  }
}
catch (e) {}

try {
  if (typeof top === 'object' && top !== null) {
    // this is a browser window

    try {
      if (typeof top.opener === 'object' && top.opener !== null && top.opener._$jscoverage) {
        top._$jscoverage = top.opener._$jscoverage;
      }
    }
    catch (e) {}

    if (! top._$jscoverage) {
      top._$jscoverage = {};
    }
  }
}
catch (e) {}

try {
  if (typeof top === 'object' && top !== null && top._$jscoverage) {
    this._$jscoverage = top._$jscoverage;
  }
}
catch (e) {}
if (! this._$jscoverage) {
  this._$jscoverage = {};
}
if (! _$jscoverage['/html-parser/nodes/comment.js']) {
  _$jscoverage['/html-parser/nodes/comment.js'] = {};
  _$jscoverage['/html-parser/nodes/comment.js'].lineData = [];
  _$jscoverage['/html-parser/nodes/comment.js'].lineData[6] = 0;
  _$jscoverage['/html-parser/nodes/comment.js'].lineData[8] = 0;
  _$jscoverage['/html-parser/nodes/comment.js'].lineData[9] = 0;
  _$jscoverage['/html-parser/nodes/comment.js'].lineData[10] = 0;
  _$jscoverage['/html-parser/nodes/comment.js'].lineData[11] = 0;
  _$jscoverage['/html-parser/nodes/comment.js'].lineData[14] = 0;
  _$jscoverage['/html-parser/nodes/comment.js'].lineData[16] = 0;
  _$jscoverage['/html-parser/nodes/comment.js'].lineData[17] = 0;
  _$jscoverage['/html-parser/nodes/comment.js'].lineData[18] = 0;
  _$jscoverage['/html-parser/nodes/comment.js'].lineData[19] = 0;
  _$jscoverage['/html-parser/nodes/comment.js'].lineData[20] = 0;
  _$jscoverage['/html-parser/nodes/comment.js'].lineData[21] = 0;
  _$jscoverage['/html-parser/nodes/comment.js'].lineData[24] = 0;
  _$jscoverage['/html-parser/nodes/comment.js'].lineData[28] = 0;
  _$jscoverage['/html-parser/nodes/comment.js'].lineData[29] = 0;
  _$jscoverage['/html-parser/nodes/comment.js'].lineData[31] = 0;
  _$jscoverage['/html-parser/nodes/comment.js'].lineData[33] = 0;
  _$jscoverage['/html-parser/nodes/comment.js'].lineData[38] = 0;
}
if (! _$jscoverage['/html-parser/nodes/comment.js'].functionData) {
  _$jscoverage['/html-parser/nodes/comment.js'].functionData = [];
  _$jscoverage['/html-parser/nodes/comment.js'].functionData[0] = 0;
  _$jscoverage['/html-parser/nodes/comment.js'].functionData[1] = 0;
  _$jscoverage['/html-parser/nodes/comment.js'].functionData[2] = 0;
  _$jscoverage['/html-parser/nodes/comment.js'].functionData[3] = 0;
}
if (! _$jscoverage['/html-parser/nodes/comment.js'].branchData) {
  _$jscoverage['/html-parser/nodes/comment.js'].branchData = {};
  _$jscoverage['/html-parser/nodes/comment.js'].branchData['17'] = [];
  _$jscoverage['/html-parser/nodes/comment.js'].branchData['17'][1] = new BranchData();
  _$jscoverage['/html-parser/nodes/comment.js'].branchData['17'][2] = new BranchData();
  _$jscoverage['/html-parser/nodes/comment.js'].branchData['18'] = [];
  _$jscoverage['/html-parser/nodes/comment.js'].branchData['18'][1] = new BranchData();
  _$jscoverage['/html-parser/nodes/comment.js'].branchData['19'] = [];
  _$jscoverage['/html-parser/nodes/comment.js'].branchData['19'][1] = new BranchData();
  _$jscoverage['/html-parser/nodes/comment.js'].branchData['28'] = [];
  _$jscoverage['/html-parser/nodes/comment.js'].branchData['28'][1] = new BranchData();
}
_$jscoverage['/html-parser/nodes/comment.js'].branchData['28'][1].init(18, 14, 'this.nodeValue');
function visit190_28_1(result) {
  _$jscoverage['/html-parser/nodes/comment.js'].branchData['28'][1].ranCondition(result);
  return result;
}_$jscoverage['/html-parser/nodes/comment.js'].branchData['19'][1].init(26, 12, 'this !== ret');
function visit189_19_1(result) {
  _$jscoverage['/html-parser/nodes/comment.js'].branchData['19'][1].ranCondition(result);
  return result;
}_$jscoverage['/html-parser/nodes/comment.js'].branchData['18'][1].init(22, 3, 'ret');
function visit188_18_1(result) {
  _$jscoverage['/html-parser/nodes/comment.js'].branchData['18'][1].ranCondition(result);
  return result;
}_$jscoverage['/html-parser/nodes/comment.js'].branchData['17'][2].init(52, 39, '(ret = filter.onComment(this)) !== false');
function visit187_17_2(result) {
  _$jscoverage['/html-parser/nodes/comment.js'].branchData['17'][2].ranCondition(result);
  return result;
}_$jscoverage['/html-parser/nodes/comment.js'].branchData['17'][1].init(40, 51, '!filter || (ret = filter.onComment(this)) !== false');
function visit186_17_1(result) {
  _$jscoverage['/html-parser/nodes/comment.js'].branchData['17'][1].ranCondition(result);
  return result;
}_$jscoverage['/html-parser/nodes/comment.js'].lineData[6]++;
KISSY.add("html-parser/nodes/comment", function(S, Text) {
  _$jscoverage['/html-parser/nodes/comment.js'].functionData[0]++;
  _$jscoverage['/html-parser/nodes/comment.js'].lineData[8]++;
  function Comment() {
    _$jscoverage['/html-parser/nodes/comment.js'].functionData[1]++;
    _$jscoverage['/html-parser/nodes/comment.js'].lineData[9]++;
    Comment.superclass.constructor.apply(this, arguments);
    _$jscoverage['/html-parser/nodes/comment.js'].lineData[10]++;
    this.nodeType = 8;
    _$jscoverage['/html-parser/nodes/comment.js'].lineData[11]++;
    this.nodeName = "#comment";
  }
  _$jscoverage['/html-parser/nodes/comment.js'].lineData[14]++;
  S.extend(Comment, Text, {
  writeHtml: function(writer, filter) {
  _$jscoverage['/html-parser/nodes/comment.js'].functionData[2]++;
  _$jscoverage['/html-parser/nodes/comment.js'].lineData[16]++;
  var ret;
  _$jscoverage['/html-parser/nodes/comment.js'].lineData[17]++;
  if (visit186_17_1(!filter || visit187_17_2((ret = filter.onComment(this)) !== false))) {
    _$jscoverage['/html-parser/nodes/comment.js'].lineData[18]++;
    if (visit188_18_1(ret)) {
      _$jscoverage['/html-parser/nodes/comment.js'].lineData[19]++;
      if (visit189_19_1(this !== ret)) {
        _$jscoverage['/html-parser/nodes/comment.js'].lineData[20]++;
        ret.writeHtml(writer, filter);
        _$jscoverage['/html-parser/nodes/comment.js'].lineData[21]++;
        return;
      }
    }
    _$jscoverage['/html-parser/nodes/comment.js'].lineData[24]++;
    writer.comment(this.toHtml());
  }
}, 
  toHtml: function() {
  _$jscoverage['/html-parser/nodes/comment.js'].functionData[3]++;
  _$jscoverage['/html-parser/nodes/comment.js'].lineData[28]++;
  if (visit190_28_1(this.nodeValue)) {
    _$jscoverage['/html-parser/nodes/comment.js'].lineData[29]++;
    return this.nodeValue;
  } else {
    _$jscoverage['/html-parser/nodes/comment.js'].lineData[31]++;
    var value = Text.superclass.toHtml.apply(this, arguments);
    _$jscoverage['/html-parser/nodes/comment.js'].lineData[33]++;
    return value.substring(4, value.length - 3);
  }
}});
  _$jscoverage['/html-parser/nodes/comment.js'].lineData[38]++;
  return Comment;
}, {
  requires: ['./text']});
